==> eclipse-linuxtools_1.2.1+dfsg.orig.tar.xz: eclipse-linuxtools-1.2.1+dfsg/lttng/org.eclipse.linuxtools.lttng2.kernel.ui.tests/src/org/eclipse/linuxtools/lttng2/kernel/ui/tests/ActivatorTest.java <==
/*******************************************************************************
 * Copyright (c) 2012 Ericsson
 *
 * All rights reserved. This program and the accompanying materials are
 * made available under the terms of the Eclipse Public License v1.0 which
 * accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   Francois Chouinard - Initial API and implementation
 *******************************************************************************/

package org.eclipse.linuxtools.lttng2.kernel.ui.tests;

import junit.framework.TestCase;

import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * <b><u>ActivatorTest</u></b>
 * <p>
 * Test suite for the Activator class
 * <p>
 */
@SuppressWarnings("javadoc")
public class ActivatorTest extends TestCase {

    // ------------------------------------------------------------------------
    // JUnit
    // ------------------------------------------------------------------------

    @BeforeClass
    public static void setUpBeforeClass() {
    }

    @AfterClass
    public static void tearDownAfterClass() {
    }

    /**
     * @throws java.lang.Exception
     */
    @Before
    @Override
    public void setUp() throws Exception {
    }

    /**
     * @throws java.lang.Exception
     */
    @After
    @Override
    public void tearDown() throws Exception {
    }

    // ------------------------------------------------------------------------
    // Tests
    // ------------------------------------------------------------------------

    /**
     * Test method for {@link org.eclipse.linuxtools.lttng2.kernel.ui.Activator#Activator()}.
     */
    @Test
    public void testActivator() {
        assertTrue(true);
    }

    /**
     * Test method for {@link org.eclipse.linuxtools.lttng2.kernel.ui.Activator#getDefault()}.
     */
    @Test
    public void testGetDefault() {
        assertTrue(true);
    }

    /**
     * Test method for {@link org.eclipse.linuxtools.lttng2.kernel.ui.Activator#start(org.osgi.framework.BundleContext)}.
     */
    @Test
    public void testStartBundleContext() {
        assertTrue(true);
    }

    /**
     * Test method for {@link org.eclipse.linuxtools.lttng2.kernel.ui.Activator#stop(org.osgi.framework.BundleContext)}.
     */
    @Test
    public void testStopBundleContext() {
        assertTrue(true);
    }

}

==> eclipse-linuxtools_3.1.0.orig.tar.xz: eclipse-linuxtools-3.1.0/lttng/org.eclipse.linuxtools.lttng2.kernel.ui.tests/src/org/eclipse/linuxtools/lttng2/kernel/ui/tests/ActivatorTest.java <==
/*******************************************************************************
 * Copyright (c) 2012, 2013 Ericsson
 *
 * All rights reserved. This program and the accompanying materials are
 * made available under the terms of the Eclipse Public License v1.0 which
 * accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   Francois Chouinard - Initial API and implementation
 *******************************************************************************/

package org.eclipse.linuxtools.lttng2.kernel.ui.tests;

import static org.junit.Assert.assertTrue;

import org.junit.Test;

/**
 * Test suite for the Activator class
 */
public class ActivatorTest {

    // ------------------------------------------------------------------------
    // Tests
    // ------------------------------------------------------------------------

    /**
     * Test method for {@link org.eclipse.linuxtools.internal.lttng2.kernel.ui.Activator#Activator()}.
     */
    @Test
    public void testActivator() {
        assertTrue(true);
    }

    /**
     * Test method for {@link org.eclipse.linuxtools.internal.lttng2.kernel.ui.Activator#getDefault()}.
     */
    @Test
    public void testGetDefault() {
        assertTrue(true);
    }

    /**
     * Test method for {@link org.eclipse.linuxtools.internal.lttng2.kernel.ui.Activator#start}.
     */
    @Test
    public void testStartBundleContext() {
        assertTrue(true);
    }

    /**
     * Test method for {@link org.eclipse.linuxtools.internal.lttng2.kernel.ui.Activator#stop}.
     */
    @Test
    public void testStopBundleContext() {
        assertTrue(true);
    }

}
